var LaunchColorChange, addBrowserMenuLinks, setColoredIcon, setGreyIcon, updateIconColor, url_domain;

LaunchColorChange = function() {
  return chrome.tabs.query({
    currentWindow: true,
    active: true
  }, function(tabArray) {
    var withoutSubDomain;
    if (tabArray[0]["url"] !== window.currentDomain) {
      window.currentDomain = url_domain(tabArray[0]["url"]).replace("www.", "");
      withoutSubDomain = Utilities.withoutSubDomain(window.currentDomain);
      if (withoutSubDomain) {
        window.currentDomain = withoutSubDomain;
      }
      return updateIconColor();
    }
  });
};

updateIconColor = function() {
  if (window.currentDomain.indexOf(".") === -1) {
    return setGreyIcon();
  } else {
    return chrome.storage.sync.get("hunter_blocked", function(value) {
      if (value["hunter_blocked"]) {
        return setColoredIcon();
      } else {
        return $.ajax({
          url: "https://extension-api.hunter.io/data-for-domain?domain=" + window.currentDomain,
          type: "GET",
          jsonp: false,
          success: function(html) {
            if (html === "1") {
              return setColoredIcon();
            } else {
              return setGreyIcon();
            }
          },
          error: function(xhr) {
            if (xhr.status === 403) {
              chrome.storage.sync.set({
                "hunter_blocked": true
              });
            }
            return setGreyIcon();
          }
        });
      }
    });
  }
};

setGreyIcon = function() {
  chrome.browserAction.setIcon({
    path: {
      "19": chrome.extension.getURL("../img/icon19_grey.png"),
      "38": chrome.extension.getURL("../img/icon38_grey.png")
    }
  });
};

setColoredIcon = function() {
  chrome.browserAction.setIcon({
    path: {
      "19": chrome.extension.getURL("../img/icon19.png"),
      "38": chrome.extension.getURL("../img/icon38.png")
    }
  });
};

url_domain = function(data) {
  var a;
  a = document.createElement("a");
  a.href = data;
  return a.hostname;
};

addBrowserMenuLinks = function() {
  chrome.contextMenus.create({
    "id": "dashboard",
    "title": "Dashboard",
    "contexts": ["browser_action"]
  });
  chrome.contextMenus.create({
    "id": "leads",
    "title": "Leads",
    "contexts": ["browser_action"]
  });
  chrome.contextMenus.create({
    "id": "subscription",
    "title": "Subscription",
    "contexts": ["browser_action"]
  });
  return chrome.contextMenus.create({
    "id": "faqs",
    "title": "Tutorial",
    "contexts": ["browser_action"]
  });
};

chrome.tabs.onUpdated.addListener(function(tabid, changeinfo, tab) {
  var url;
  url = tab.url;
  if (url !== void 0 && changeinfo.status === "complete") {
    return LaunchColorChange();
  }
});

chrome.tabs.onActivated.addListener(function() {
  return LaunchColorChange();
});

addBrowserMenuLinks();

chrome.contextMenus.onClicked.addListener(function(info, tab) {
  switch (info.menuItemId) {
    case "dashboard":
      chrome.tabs.create({
        url: "https://hunter.io/dashboard?utm_source=chrome_extension&utm_medium=chrome_extension&utm_campaign=extension&utm_content=context_menu_browser_action"
      });
      break;
    case "leads":
      chrome.tabs.create({
        url: "https://hunter.io/leads?utm_source=chrome_extension&utm_medium=chrome_extension&utm_campaign=extension&utm_content=context_menu_browser_action"
      });
      break;
    case "subscription":
      chrome.tabs.create({
        url: "https://hunter.io/subscriptions?utm_source=chrome_extension&utm_medium=chrome_extension&utm_campaign=extension&utm_content=context_menu_browser_action"
      });
      break;
    case "faqs":
      chrome.tabs.create({
        url: "https://hunter.io/help/articles/2-hunter-s-chrome-extension?utm_source=chrome_extension&utm_medium=chrome_extension&utm_campaign=extension&utm_content=context_menu_browser_action"
      });
  }
});

chrome.runtime.onInstalled.addListener(function(object) {
  if (object.reason === "install") {
    chrome.tabs.create({
      url: "https://hunter.io/users/sign_up?utm_source=chrome_extension&utm_medium=chrome_extension&utm_campaign=extension&utm_content=new_install"
    });
  }
});

chrome.runtime.setUninstallURL("https://hunter.io/chrome/uninstall?utm_source=chrome_extension&utm_medium=chrome_extension&utm_campaign=extension&utm_content=uninstall");
