chrome.runtime.onMessage.addListener(function(request, sender, sendResponse) {
  var open_graph_type;
  if (request.parsing === "article") {
    open_graph_type = $("meta[property='og:type']").attr("content");
    if (open_graph_type === "article") {
      return sendResponse({
        is_article: true
      });
    } else {
      return sendResponse({
        is_article: false
      });
    }
  }
});

var PageContent, email;

PageContent = {
  getEmailInHash: function() {
    var email, hash;
    if (window.location.hash) {
      hash = window.location.hash;
      if (hash.indexOf(":") !== -1 && hash.split(":")[0]) {
        email = hash.split(":")[1];
        if (this.validateEmail(email)) {
          return email;
        } else {
          return false;
        }
      } else {
        return false;
      }
    } else {
      return false;
    }
  },
  validateEmail: function(email) {
    var re;
    re = /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
    return re.test(email);
  },
  highlightEmail: function(email) {
    var _this, context, instance, options;
    _this = this;
    options = {
      "element": "mark",
      "className": "hunter-email",
      "done": function(counter) {
        if (counter > 0) {
          _this.scrollToEmail();
          _this.addLocationIcon();
          _this.displayMessage("found", email, counter);
        } else {
          _this.highlightMailto(email);
        }
      }
    };
    context = document.querySelector("body");
    instance = new Mark(context);
    return instance.mark(email, options);
  },
  highlightMailto: function(email) {
    if ($("a[href=\"mailto:" + email + "\"]").length) {
      $("a[href=\"mailto:" + email + "\"]").addClass("hunter-email");
      this.scrollToEmail();
      this.addLocationIcon();
      return this.displayMessage("mailto", email, 1);
    } else {
      return this.searchCode(email);
    }
  },
  searchCode: function(email) {
    if ($("html").html().indexOf(email) !== -1) {
      return this.displayMessage("code", email, 0);
    } else {
      return this.displayMessage("notfound", email, 0);
    }
  },
  scrollToEmail: function() {
    return $("html, body").animate({
      scrollTop: $(".hunter-email:first").offset().top - 300
    }, 500);
  },
  addLocationIcon: function() {
    return $(".hunter-email").each(function(index) {
      var emailEl, emailHeight, emailWidth, position;
      emailEl = $(this);
      position = emailEl.offset();
      emailWidth = emailEl.outerWidth();
      emailHeight = emailEl.outerHeight();
      $("body").prepend("<img src=\"" + DOMPurify.sanitize(chrome.extension.getURL("/img/location_icon.png")) + "\" alt=\"Here is the email found with Hunter!\" id=\"hunter-email-pointer\"/>");
      $("#hunter-email-pointer").css({
        "top": position.top - 63,
        "left": position.left + emailWidth / 2 - 25
      });
      return $("#hunter-email-pointer").delay(1000).fadeIn(500);
    });
  },
  displayMessage: function(message, email, count) {
    var src;
    src = chrome.extension.getURL("/html/source_popup.html") + "?email=" + email + "&count=" + count + "&message=" + message;
    $("body").prepend("<iframe id='hunter-email-status' src='" + src + "'></iframe>");
    $("body").prepend("<div id='hunter-email-status-close'>&times;</div>");
    $("#hunter-email-status, #hunter-email-status-close").delay(500).fadeIn();
    return $("#hunter-email-status-close").on("click", function() {
      return $("#hunter-email-status, #hunter-email-status-close, #hunter-email-pointer").fadeOut();
    });
  }
};

email = PageContent.getEmailInHash();

if (email) {
  PageContent.highlightEmail(email);
}
